@@ -16,6 +16,7 @@ from pacroller.config import (CONFIG_DIR, CONFIG_FILE, LIB_DIR, DB_FILE, PACMAN_
                               TIMEOUT, UPGRADE_TIMEOUT, NETWORK_RETRY, CUSTOM_SYNC, SYNC_SH,
                               EXTRA_SAFE, SHELL, HOLD, NEEDRESTART, NEEDRESTART_CMD, SYSTEMD,
                               PACMAN_PKG_DIR, PACMAN_SCC, PACMAN_DB_LCK, SAVE_STDOUT, LOG_DIR)
+from pacroller.mailer import MailSender
 
 logger = logging.getLogger()
 
@@ -67,9 +68,10 @@ def sync() -> None:
 
 def upgrade(interactive=False) -> List[str]:
     logger.info('upgrade start')
-    check_upgrade_cmd = ['pacman', '-Qu', '--color', 'never']
-    p = subprocess.run(
-        check_upgrade_cmd,
+    query_upgrade_cmd = ['pacman', '-Qu', '--color', 'never']
+    sync_upgrade_cmd = ['pacman', '-Su', '--print-format', '%n %v', '--color', 'never']
+    qp = subprocess.run(
+        query_upgrade_cmd,
         stdin=subprocess.DEVNULL,
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
@@ -77,10 +79,20 @@ def upgrade(interactive=False) -> List[str]:
         timeout=TIMEOUT,
         check=False
     )
-    if p.returncode != 1:
-        p.check_returncode()
+    if qp.returncode != 1:
+        qp.check_returncode()
+    sp = subprocess.run(
+        sync_upgrade_cmd,
+        stdin=subprocess.DEVNULL,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT,
+        encoding='utf-8',
+        timeout=TIMEOUT,
+        check=True
+    )
+    upgrade_pkgnames = list()
     upgrade_pkgs = list()
-    for line in filter(None, p.stdout.split('\n')):
+    for line in filter(None, qp.stdout.split('\n')):
         pkgname, over, _ar, nver, *ignored = line.split()
         assert _ar == '->'
         assert not ignored or (len(ignored) == 1 and ignored[0] == "[ignored]")
@@ -89,6 +101,12 @@ def upgrade(interactive=False) -> List[str]:
         else:
             logger.debug(f"upgrade: {pkgname} {over} -> {nver}")
             upgrade_pkgs.append((pkgname, over, nver))
+            upgrade_pkgnames.append(pkgname)
+    for line in filter(None, sp.stdout.split('\n')):
+        pkgname, nver = line.split()
+        if pkgname not in upgrade_pkgnames:
+            logger.debug(f"install: {pkgname} {nver}")
+            upgrade_pkgs.append((pkgname, '', nver))
     if not upgrade_pkgs:
         logger.info('upgrade end, nothing to do')
         exit(0)
@@ -97,15 +115,18 @@ def upgrade(interactive=False) -> List[str]:
             errors = list()
             for pkgname, over, nver in upgrade_pkgs:
                 if _testreg := HOLD.get(pkgname):
-                    _m_old = match(_testreg, over)
-                    _m_new = match(_testreg, nver)
-                    if _m_old and _m_new:
-                        if (o := _m_old.groups()) != (n := _m_new.groups()):
-                            errors.append(f"hold package {pkgname} is going to be upgraded from {o=} to {n=}")
-                        if not o or not n:
-                            errors.append(f"hold package {pkgname}: version regex missing matching groups {o=} {n=}")
+                    if over:
+                        _m_old = match(_testreg, over)
+                        _m_new = match(_testreg, nver)
+                        if _m_old and _m_new:
+                            if (o := _m_old.groups()) != (n := _m_new.groups()):
+                                errors.append(f"hold package {pkgname} is going to be upgraded from {over} to {nver}")
+                            if not o or not n:
+                                errors.append(f"hold package {pkgname}: version regex missing matching groups {over=} {nver=} {o=} {n=}")
+                        else:
+                            errors.append(f"cannot match version regex for hold package {pkgname}")
                     else:
-                        errors.append(f"cannot match version regex for hold package {pkgname}")
+                        errors.append(f"hold package {pkgname} {nver} is going to be installed")
             if errors:
                 raise PackageHold(errors)
         except PackageHold as e:
@@ -263,8 +284,8 @@ def main() -> None:
             logger.debug(f'needrestart {p.stdout=}')
     import argparse
     parser = argparse.ArgumentParser(description='Unattended Upgrades for Arch Linux')
-    parser.add_argument('action', choices=['run', 'status', 'reset', 'fail-reset', 'reset-failed'],
-                        help="what to do", metavar="run / status / reset ")
+    parser.add_argument('action', choices=['run', 'status', 'reset', 'fail-reset', 'reset-failed', 'test-smtp'],
+                        help="what to do", metavar="run / status / reset / test-smtp")
     parser.add_argument('-d', '--debug', action='store_true', help='enable debug mode')
     parser.add_argument('-v', '--verbose', action='store_true', help='show verbose report')
     parser.add_argument('-m', '--max', type=int, default=1, help='Number of upgrades to show')
@@ -280,6 +301,7 @@ def main() -> None:
     locale_set()
     interactive = args.interactive == "on" or not (args.interactive == 'off' or not isatty(0))
     logger.debug(f"interactive questions {'enabled' if interactive else 'disabled'}")
+    send_mail = MailSender().send_text_plain if not interactive else lambda *_: None
 
     if args.action == 'run':
         if getuid() != 0:
@@ -290,28 +312,44 @@ def main() -> None:
             exit(2)
         if SYSTEMD:
             if _s := is_system_failed():
-                logger.error(f'systemd is in {_s} state, refused')
+                _err = f'systemd is in {_s} state, refused'
+                logger.error(_err)
+                send_mail(_err)
                 exit(11)
         if Path(PACMAN_DB_LCK).exists():
-            logger.error(f'Database is locked at {PACMAN_DB_LCK}')
+            _err = f'Database is locked at {PACMAN_DB_LCK}'
+            logger.error(_err)
+            send_mail(_err)
             exit(2)
         try:
             report = do_system_upgrade(debug=args.debug, interactive=interactive)
         except NonFatal:
+            send_mail(f"NonFatal Error:\n{traceback.format_exc()}")
             raise
         except Exception as e:
             write_db(None, e)
+            send_mail(f"Fatal Error:\n{traceback.format_exc()}")
             raise
         else:
             exc = CheckFailed('manual inspection required') if report.failed else None
             write_db(report, exc)
             if exc:
+                send_mail(f"{exc}\n\n{report.summary(verbose=args.verbose, show_package=False)}")
                 exit(2)
             if NEEDRESTART:
                 run_needrestart()
             if PACMAN_SCC:
                 clear_pkg_cache()
 
+    elif args.action == 'test-smtp':
+        logger.info('sending test mail...')
+        if _smtp_result := MailSender().send_text_plain("This is a test mail\nIf you see this email, your smtp config is working."):
+            logger.info("success")
+        elif _smtp_result is None:
+            logger.warning("smtp is disabled")
+        else:
+            logger.error("fail")
+
     elif args.action == 'status':
         count = 0
         failed = False
